cygenja documentation — cygenja 0.5.1 documentation

# cygenja documentation

Release: | 0.5
Date: | May 17, 2016

- Introduction
  - What cygenja can do
  - How cygenja works
  - Limitations
  - License
- Installing cygenja
  - Dependencies
  - Installation
- Usage
  - The Generator class
  - Patterns
  - The root directory
  - Filters
  - File extensions
  - Actions
  - File generation
- Examples
  - Init
  - File extensions
  - Filters
  - Actions
  - File generation

## Indices and Tables

- Index
- Search Page